# encoding: utf-8

require 'spec_helper'

describe MTG::API::Card do
  subject { MTG::API::Card }

  describe 'when search card' do
    context 'by id' do
      let(:valid_card)   { subject.find_by_id(1) }
      let(:invalid_card) { subject.find_by_id(0) }

      it 'with invalid id', vcr: { cassette_name: 'find_by_invalid_id' } do
        expect(invalid_card).to respond_to(:Error)
      end

      it 'with valid id', vcr: { cassette_name: 'find_by_valid_id' } do
        expect(valid_card).to_not respond_to(:Error)

        expect(valid_card.id).to         eql "1"
        expect(valid_card.name).to       eql "Ankh of Mishra"
        expect(valid_card.mana).to       eql ["2"]
        expect(valid_card.cmc).to        eql "2"
        expect(valid_card.type).to       eql ["Artifact"]
        expect(valid_card.text).to       eql ["Whenever a land enters the battlefield, Ankh of Mishra deals 2 damage to that land's controller."]
        expect(valid_card.flavor).to     be_empty
        expect(valid_card.power).to      be_empty
        expect(valid_card.toughness).to  be_empty
        expect(valid_card.loyalty).to    be_empty
        expect(valid_card.watermark).to  be_empty
        expect(valid_card.set).to        eql "Limited Edition Alpha"
        expect(valid_card.rarity).to     eql "Rare"
        expect(valid_card.number).to     be_empty
        expect(valid_card.artist).to     eql "Amy Weber"
        expect(valid_card.prints).to     eql [{"set" => "1E", "id" => "1"},
                                              {"set" => "2E", "id" => "296"},
                                              {"set" => "2U", "id" => "598"},
                                              {"set" => "3E", "id" => "1094"},
                                              {"set" => "4E", "id" => "2017"},
                                              {"set" => "5E", "id" => "3760"},
                                              {"set" => "6E", "id" => "14771"},
                                              {"set" => "MED", "id" => "159251"}]
      end
    end

    context 'by text' do
      let(:valid_cards)  { subject.find_by_text('tundra') }
      let(:invalid_card) { subject.find_by_text('invalid-name') }

      it 'with invalid card name', vcr: { cassette_name: 'find_by_invalid_text' } do
        pending 'API is raising {"code":"500","error":"internal server error"} so far :('
        expect(invalid_card).to raise_error(/500 - Internal Server Error/)
      end

      it 'with valid card name', vcr: { cassette_name: 'find_by_valid_text' } do
        valid_card = valid_cards.first

        expect(valid_cards).to have(3).cards

        expect(valid_card).to_not respond_to(:Error)

        expect(valid_card.id).to         eql "202424"
        expect(valid_card.name).to       eql "Tundra"
        expect(valid_card.mana).to       be_empty
        expect(valid_card.cmc).to        be_empty
        expect(valid_card.type).to       eql ["Land ", "Plains Island"]
        expect(valid_card.text).to       be_empty
        expect(valid_card.flavor).to     be_empty
        expect(valid_card.power).to      be_empty
        expect(valid_card.toughness).to  be_empty
        expect(valid_card.loyalty).to    be_empty
        expect(valid_card.watermark).to  be_empty
        expect(valid_card.set).to        eql "Masters Edition IV"
        expect(valid_card.rarity).to     eql "Rare"
        expect(valid_card.number).to     eql "255"
        expect(valid_card.artist).to     eql "Jesper Myrfors"
        expect(valid_card.prints).to     eql [{"set" => "1E", "id" => "286"},
                                              {"set" => "2E", "id" => "583"},
                                              {"set" => "2U", "id" => "885"},
                                              {"set" => "3E", "id" => "1383"},
                                              {"set" => "ME2", "id" => "184751"},
                                              {"set" => "ME4", "id" => "202424"}]
      end
    end
  end
end
